
import UIKit

class DocumentsViewController: UITableViewController {
    var documentsList: [String] = []
    var metaData: NSMetadataQuery!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        let center = NotificationCenter.default
        center.addObserver(self, selector: #selector(updateList(notification:)), name: NSNotification.Name.NSMetadataQueryDidFinishGathering, object: nil)
        center.addObserver(self, selector: #selector(updateList(notification:)), name: NSNotification.Name.NSMetadataQueryDidUpdate, object: nil)
        
        metaData = NSMetadataQuery()
        metaData.searchScopes = [NSMetadataQueryUbiquitousDocumentsScope]
        metaData.start()
    }
    @objc func updateList(notification: NSNotification) {
        metaData.disableUpdates()
        for item in metaData.results as! [NSMetadataItem] {
            let name = item.value(forAttribute: NSMetadataItemFSNameKey) as! String
            if documentsList.index(of: name) == nil {
                documentsList.append(name)
            }
        }
        documentsList.sort(by: { (value1, value2) in value1 < value2 })
        
        tableView.reloadData()
        metaData.enableUpdates()
    }
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return documentsList.count
    }
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "documentCell", for: indexPath)
        cell.textLabel?.text = documentsList[indexPath.row]
        return cell
    }
    override func prepare(for segue: UIStoryboardSegue, sender: Any?){
        if segue.identifier == "showDocument" {
            let controller = segue.destination as! EditionViewController
            if let path = tableView.indexPathForSelectedRow {
                controller.selected = documentsList[path.row]
            }
        }
    }
    @IBAction func addDocument(_ sender: UIBarButtonItem) {
        let alert = UIAlertController(title: "New File", message: nil, preferredStyle: .alert)
        let cancel = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        alert.addAction(cancel)
        let action = UIAlertAction(title: "Create", style: .default, handler: { (action) in
            if let fields = alert.textFields {
                let file = fields[0].text
                self.saveFile(name: file!)
            }
        })
        alert.addAction(action)
        alert.addTextField(configurationHandler: { (textField) in
            textField.placeholder = "Insert name and extension"
        })
        present(alert, animated: true, completion: nil)
    }
    func saveFile(name: String) {
        if documentsList.index(of: name) == nil {
            let manager = FileManager.default
            if let fileURL = manager.url(forUbiquityContainerIdentifier: nil) {
                let iCloudURL = fileURL.appendingPathComponent("Documents/\(name)")
                let document = MyDocument(fileURL: iCloudURL)
                document.save(to: iCloudURL, for: .forCreating, completionHandler: nil)
            }
        }
    }
}
